Struct Awsr
#[repr(transparent)]pub struct Awsr(pub u32);Tuple Fields
0: u32Implementations
impl Awsr
impl Awsr
pub const fn awltf(&self) -> u8
pub const fn awltf(&self) -> u8
Analog watchdog low threshold flag AWLTF[y]=1 indicates a low threshold error on channel y. It is set by hardware. It can be cleared by software using the corresponding CLRAWLTF[y] bit in the DFSDM_FLTxAWCFR register.
pub const fn set_awltf(&mut self, val: u8)
pub const fn set_awltf(&mut self, val: u8)
Analog watchdog low threshold flag AWLTF[y]=1 indicates a low threshold error on channel y. It is set by hardware. It can be cleared by software using the corresponding CLRAWLTF[y] bit in the DFSDM_FLTxAWCFR register.