Struct Isr
#[repr(transparent)]pub struct Isr(pub u32);Tuple Fields
0: u32Implementations
impl Isr
impl Isr
pub const fn jeocf(&self) -> bool
pub const fn jeocf(&self) -> bool
End of injected conversion flag This bit is set by hardware. It is cleared when the software or DMA reads DFSDM_FLTxJDATAR.
pub const fn set_jeocf(&mut self, val: bool)
pub const fn set_jeocf(&mut self, val: bool)
End of injected conversion flag This bit is set by hardware. It is cleared when the software or DMA reads DFSDM_FLTxJDATAR.
pub const fn reocf(&self) -> bool
pub const fn reocf(&self) -> bool
End of regular conversion flag This bit is set by hardware. It is cleared when the software or DMA reads DFSDM_FLTxRDATAR.
pub const fn set_reocf(&mut self, val: bool)
pub const fn set_reocf(&mut self, val: bool)
End of regular conversion flag This bit is set by hardware. It is cleared when the software or DMA reads DFSDM_FLTxRDATAR.
pub const fn jovrf(&self) -> bool
pub const fn jovrf(&self) -> bool
Injected conversion overrun flag This bit is set by hardware. It can be cleared by software using the CLRJOVRF bit in the DFSDM_FLTxICR register.
pub const fn set_jovrf(&mut self, val: bool)
pub const fn set_jovrf(&mut self, val: bool)
Injected conversion overrun flag This bit is set by hardware. It can be cleared by software using the CLRJOVRF bit in the DFSDM_FLTxICR register.
pub const fn rovrf(&self) -> bool
pub const fn rovrf(&self) -> bool
Regular conversion overrun flag This bit is set by hardware. It can be cleared by software using the CLRROVRF bit in the DFSDM_FLTxICR register.
pub const fn set_rovrf(&mut self, val: bool)
pub const fn set_rovrf(&mut self, val: bool)
Regular conversion overrun flag This bit is set by hardware. It can be cleared by software using the CLRROVRF bit in the DFSDM_FLTxICR register.
pub const fn awdf(&self) -> bool
pub const fn awdf(&self) -> bool
Analog watchdog This bit is set by hardware. It is cleared by software by clearing all source flag bits AWHTF[7:0] and AWLTF[7:0] in DFSDM_FLTxAWSR register (by writing ‘1’ into the clear bits in DFSDM_FLTxAWCFR register).
pub const fn set_awdf(&mut self, val: bool)
pub const fn set_awdf(&mut self, val: bool)
Analog watchdog This bit is set by hardware. It is cleared by software by clearing all source flag bits AWHTF[7:0] and AWLTF[7:0] in DFSDM_FLTxAWSR register (by writing ‘1’ into the clear bits in DFSDM_FLTxAWCFR register).
pub const fn jcip(&self) -> bool
pub const fn jcip(&self) -> bool
Injected conversion in progress status A request to start an injected conversion is ignored when JCIP=1.
pub const fn set_jcip(&mut self, val: bool)
pub const fn set_jcip(&mut self, val: bool)
Injected conversion in progress status A request to start an injected conversion is ignored when JCIP=1.
pub const fn rcip(&self) -> bool
pub const fn rcip(&self) -> bool
Regular conversion in progress status A request to start a regular conversion is ignored when RCIP=1.
pub const fn set_rcip(&mut self, val: bool)
pub const fn set_rcip(&mut self, val: bool)
Regular conversion in progress status A request to start a regular conversion is ignored when RCIP=1.
pub const fn ckabf(&self) -> u8
pub const fn ckabf(&self) -> u8
Clock absence flag CKABF[y]=0: Clock signal on channel y is present. CKABF[y]=1: Clock signal on channel y is not present. Given y bit is set by hardware when clock absence is detected on channel y. It is held at CKABF[y]=1 state by hardware when CHEN=0 (see DFSDM_CHyCFGR1 register). It is held at CKABF[y]=1 state by hardware when the transceiver is not yet synchronized.It can be cleared by software using the corresponding CLRCKABF[y] bit in the DFSDM_FLTxICR register. Note: CKABF[7:0] is present only in DFSDM_FLT0ISR register (filter x=0).
pub const fn set_ckabf(&mut self, val: u8)
pub const fn set_ckabf(&mut self, val: u8)
Clock absence flag CKABF[y]=0: Clock signal on channel y is present. CKABF[y]=1: Clock signal on channel y is not present. Given y bit is set by hardware when clock absence is detected on channel y. It is held at CKABF[y]=1 state by hardware when CHEN=0 (see DFSDM_CHyCFGR1 register). It is held at CKABF[y]=1 state by hardware when the transceiver is not yet synchronized.It can be cleared by software using the corresponding CLRCKABF[y] bit in the DFSDM_FLTxICR register. Note: CKABF[7:0] is present only in DFSDM_FLT0ISR register (filter x=0).
pub const fn scdf(&self) -> u8
pub const fn scdf(&self) -> u8
Short-circuit detector flag SDCF[y]=0: No short-circuit detector event occurred on channel y SDCF[y]=1: The short-circuit detector counter reaches, on channel y, the value programmed in the DFSDM_CHyAWSCDR registers This bit is set by hardware. It can be cleared by software using the corresponding CLRSCDF[y] bit in the DFSDM_FLTxICR register. SCDF[y] is cleared also by hardware when CHEN[y] = 0 (given channel is disabled). Note: SCDF[7:0] is present only in DFSDM_FLT0ISR register (filter x=0).
pub const fn set_scdf(&mut self, val: u8)
pub const fn set_scdf(&mut self, val: u8)
Short-circuit detector flag SDCF[y]=0: No short-circuit detector event occurred on channel y SDCF[y]=1: The short-circuit detector counter reaches, on channel y, the value programmed in the DFSDM_CHyAWSCDR registers This bit is set by hardware. It can be cleared by software using the corresponding CLRSCDF[y] bit in the DFSDM_FLTxICR register. SCDF[y] is cleared also by hardware when CHEN[y] = 0 (given channel is disabled). Note: SCDF[7:0] is present only in DFSDM_FLT0ISR register (filter x=0).