stm32-metapac

Crates

git

Versions

stm32f412cg

Flavors

Jdatar

Struct Jdatar 

#[repr(transparent)]
pub struct Jdatar(pub u32);

Tuple Fields

0: u32

Implementations



impl Jdatar

pub const fn jdatach(&self) -> u8

Injected channel most recently converted When each conversion of a channel in the injected group finishes, JDATACH[2:0] is updated to indicate which channel was converted. Thus, JDATA[23:0] holds the data that corresponds to the channel indicated by JDATACH[2:0].

pub const fn set_jdatach(&mut self, val: u8)

Injected channel most recently converted When each conversion of a channel in the injected group finishes, JDATACH[2:0] is updated to indicate which channel was converted. Thus, JDATA[23:0] holds the data that corresponds to the channel indicated by JDATACH[2:0].

pub const fn jdata(&self) -> u32

Injected group conversion data When each conversion of a channel in the injected group finishes, its resulting data is stored in this field. The data is valid when JEOCF=1. Reading this register clears the corresponding JEOCF.

pub const fn set_jdata(&mut self, val: u32)

Injected group conversion data When each conversion of a channel in the injected group finishes, its resulting data is stored in this field. The data is valid when JEOCF=1. Reading this register clears the corresponding JEOCF.