Struct Jdatar
#[repr(transparent)]pub struct Jdatar(pub u32);Tuple Fields
0: u32Implementations
impl Jdatar
impl Jdatar
pub const fn jdatach(&self) -> u8
pub const fn jdatach(&self) -> u8
Injected channel most recently converted When each conversion of a channel in the injected group finishes, JDATACH[2:0] is updated to indicate which channel was converted. Thus, JDATA[23:0] holds the data that corresponds to the channel indicated by JDATACH[2:0].
pub const fn set_jdatach(&mut self, val: u8)
pub const fn set_jdatach(&mut self, val: u8)
Injected channel most recently converted When each conversion of a channel in the injected group finishes, JDATACH[2:0] is updated to indicate which channel was converted. Thus, JDATA[23:0] holds the data that corresponds to the channel indicated by JDATACH[2:0].